@@ -2,11 +2,12 @@ import logging
 import os
 
 from dbnd._core.configuration.environ_config import in_quiet_mode
-from dbnd._core.errors.friendly_error.versioned_dagbag import failed_to_load_versioned_dagbag_plugin
+from dbnd._core.errors.friendly_error.versioned_dagbag import (
+    failed_to_load_versioned_dagbag_plugin
+)
 from dbnd._core.utils.object_utils import patch_module_attr
 from dbnd_airflow.constants import AIRFLOW_VERSION_2
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -24,7 +25,10 @@ def _use_databand_airflow_dagbag():
     else:
         from airflow.www_rbac import views
 
-    from dbnd_airflow.web.databand_versioned_dagbag import DbndAirflowDagBag, DbndDagModel
+    from dbnd_airflow.web.databand_versioned_dagbag import (
+        DbndAirflowDagBag,
+        DbndDagModel
+    )
 
     if os.environ.get("SKIP_DAGS_PARSING") != "True":
         views.dagbag = DbndAirflowDagBag(settings.DAGS_FOLDER)
@@ -64,7 +68,7 @@ def patch_airflow_create_app():
     if AIRFLOW_VERSION_2:
         from airflow.www import app as airflow_app_rbac
     else:
-        from airflow.www_rbac import app  as airflow_app_rbac
+        from airflow.www_rbac import app as airflow_app_rbac
 
     airflow_app_rbac.create_app = patch_create_app(airflow_app_rbac.create_app)
 
